@@ -59,7 +59,8 @@ class TransmitterSerializer(serializers.ModelSerializer):
         fields = (
             'uuid', 'description', 'alive', 'type', 'uplink_low', 'uplink_high', 'uplink_drift',
             'downlink_low', 'downlink_high', 'downlink_drift', 'mode', 'mode_id', 'uplink_mode',
-            'invert', 'baud', 'norad_cat_id', 'status', 'updated', 'citation', 'service'
+            'invert', 'baud', 'norad_cat_id', 'status', 'updated', 'citation', 'service',
+            'coordination', 'coordination_url'
         )
 
     # Keeping alive field for compatibility issues
@@ -69,7 +70,10 @@ class TransmitterSerializer(serializers.ModelSerializer):
 
     def get_mode_id(self, obj):
         """Returns downlink mode id"""
-        return obj.downlink_mode.id
+        try:
+            return obj.downlink_mode.id
+        except AttributeError:  # rare chance that this happens in prod
+            return None
 
     def get_mode(self, obj):
         """Returns downlink mode name"""
