@@ -7,13 +7,14 @@ from datetime import datetime, timedelta
 
 from celery import shared_task
 from django.conf import settings
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.contrib.sites.models import Site
 from django.core.exceptions import ValidationError
 from django.core.files import File
 from django.core.mail import send_mail
 from django.core.validators import URLValidator
 from django.template.loader import render_to_string
+from django.urls import reverse
 from django.utils.timezone import make_aware
 from satellite_tle import fetch_all_tles, fetch_tle_from_celestrak, fetch_tles
 from sgp4.earth_gravity import wgs72
@@ -177,7 +178,7 @@ def remove_old_exported_framesets():
 def export_frames(norad, user_id, period=None):
     """Task to export satellite frames in csv."""
     exported_frameset = ExportedFrameset()
-    exported_frameset.user = User.objects.get(pk=user_id)
+    exported_frameset.user = get_user_model().objects.get(pk=user_id)
     exported_frameset.satellite = Satellite.objects.get(norad_cat_id=norad)
     exported_frameset.end = datetime.utcnow()
 
@@ -230,6 +231,35 @@ def notify_user_export(url, norad, email):
     send_mail(subject, message, settings.DEFAULT_FROM_EMAIL, [email], False)
 
 
+@shared_task
+def notify_transmitter_suggestion(satellite_id, user_id):
+    """Helper function to email admin users when a new transmitter suggestion
+    is submitted"""
+    satellite = Satellite.objects.get(pk=satellite_id)
+    user = get_user_model().objects.get(pk=user_id)
+
+    # Notify admins
+    admins = get_user_model().objects.filter(is_superuser=True)
+    site = Site.objects.get_current()
+    subject = '[{0}] A new suggestion for {1} was submitted'.format(site.name, satellite.name)
+    template = 'emails/new_transmitter_suggestion.txt'
+    saturl = '{0}{1}'.format(
+        site.domain, reverse('satellite', kwargs={'norad': satellite.norad_cat_id})
+    )
+    data = {
+        'satname': satellite.name,
+        'saturl': saturl,
+        'suggestion_count': satellite.transmitter_suggestion_count,
+        'contributor': user
+    }
+    message = render_to_string(template, {'data': data})
+    for user in admins:
+        try:
+            user.email_user(subject, message, from_email=settings.DEFAULT_FROM_EMAIL)
+        except Exception:  # pylint: disable=W0703
+            LOGGER.error('Could not send email to user', exc_info=True)
+
+
 @shared_task
 def background_cache_statistics():
     """Task to periodically cache statistics"""
