@@ -5,7 +5,7 @@ from datetime import datetime, timedelta
 
 import factory
 import pytest
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.test import TestCase
 from django.utils.timezone import now
 from factory import fuzzy
@@ -55,7 +55,7 @@ class UserFactory(factory.django.DjangoModelFactory):
     username = factory.Sequence(lambda n: "user_%d" % n)
 
     class Meta:
-        model = User
+        model = get_user_model()
 
 
 class SatelliteFactory(factory.django.DjangoModelFactory):
@@ -110,6 +110,12 @@ class TransmitterSuggestionFactory(factory.django.DjangoModelFactory):
     created = fuzzy.FuzzyDateTime(now() - timedelta(days=30), now())
     citation = fuzzy.FuzzyText()
     user = factory.SubFactory(UserFactory)
+    service = fuzzy.FuzzyChoice(
+        choices=['Amateur', 'Broadcasting', 'Earth Exploration', 'Fixed', 'Inter-satellite']
+    )
+    coordination = fuzzy.FuzzyChoice(
+        choices=['', 'IARU Requested', 'IARU Rejected', 'IARU Coordinated', 'Uncoordinated']
+    )
 
     class Meta:
         model = TransmitterSuggestion
