@@ -188,4 +188,29 @@ $(document).ready(function () {
             $('#dataChartError').removeClass('d-none');
         }
     });
+
+    // Handle deep linking of tabbed panes
+    let url = location.href.replace(/\/$/, '');
+    history.replaceState(null, null, url);
+
+    if (location.hash) {
+        const hash = url.split('#');
+        $('#tabs a[href="#' + hash[1] + '"]').tab('show');
+        url = location.href.replace(/\/#/, '#');
+        history.replaceState(null, null, url);
+        setTimeout(() => {
+            $(window).scrollTop(0);
+        }, 400);
+    }
+
+    $('a[data-toggle="tab"]').on('click', function () {
+        let newUrl;
+        const hash = $(this).attr('href');
+        if (hash == '#profile') {
+            newUrl = url.split('#')[0];
+        } else {
+            newUrl = url.split('#')[0] + hash;
+        }
+        history.replaceState(null, null, newUrl);
+    });
 });
